@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 from functools import wraps
@@ -210,38 +210,6 @@ class URL(object):
         return inner
 
 
-class BrowserParamURL(URL):
-    """A URL that automatically fills some params from browser attributes.
-
-    URL patterns having groups named "browser_*" will pick the relevant
-    attribute from the browser. For example:
-
-        foo = BrowserParamURL(r'/foo\?bar=(?P<browser_token>\w+)')
-
-    The browser is expected to have a `.token` attribute and it will be passed
-    automatically when just calling `foo.go()`, it's equivalent to
-    `foo.go(browser_token=browser.token)`.
-
-    Warning: all `browser_*` params will be passed, having multiple patterns
-    with different groups in a `BrowserParamURL` is risky.
-    """
-
-    def build(self, **kwargs):
-        prefix = 'browser_'
-
-        for arg in kwargs:
-            if arg.startswith(prefix):
-                raise ValueError('parameter %r is reserved by URL pattern')
-
-        for url in self.urls:
-            for groupname in re.compile(url).groupindex:
-                if groupname.startswith(prefix):
-                    attrname = groupname[len(prefix):]
-                    kwargs[groupname] = getattr(self.browser, attrname)
-
-        return super(BrowserParamURL, self).build(**kwargs)
-
-
 def normalize_url(url):
     """Normalize URL by lower-casing the domain and other fixes.
 
