@@ -236,23 +236,23 @@ class ChaoticDateGuesser(LinearDateGuesser):
 
 
 DATE_TRANSLATE_FR = [(re.compile(u'janvier', re.I),   u'january'),
-                     (re.compile(u'février', re.I),   u'february'),
+                     (re.compile(u'f[eé]vrier', re.I | re.U),   u'february'),
                      (re.compile(u'mars', re.I),      u'march'),
                      (re.compile(u'avril', re.I),     u'april'),
                      (re.compile(u'mai', re.I),       u'may'),
                      (re.compile(u'juin', re.I),      u'june'),
                      (re.compile(u'juillet', re.I),   u'july'),
-                     (re.compile(u'ao[uû]t?', re.I),  u'august'),
+                     (re.compile(u'ao[uû]t?', re.I | re.U),  u'august'),
                      (re.compile(u'septembre', re.I), u'september'),
                      (re.compile(u'octobre', re.I),   u'october'),
                      (re.compile(u'novembre', re.I),  u'november'),
-                     (re.compile(u'd[ée]cembre', re.I),u'december'),
+                     (re.compile(u'd[eé]cembre', re.I | re.U),u'december'),
                      (re.compile(u'jan\\.', re.I),    u'january'),
                      (re.compile(u'janv\\.', re.I),   u'january'),
                      (re.compile(u'\\bjan\\b', re.I), u'january'),
-                     (re.compile(u'fév\\.', re.I),    u'february'),
-                     (re.compile(u'févr\\.', re.I),   u'february'),
-                     (re.compile(u'\\bfév\\b', re.I), u'february'),
+                     (re.compile(u'f[eé]v\\.', re.I | re.U),    u'february'),
+                     (re.compile(u'f[eé]vr\\.', re.I | re.U),   u'february'),
+                     (re.compile(u'\\bf[eé]v\\b', re.I | re.U), u'february'),
                      (re.compile(u'avr\\.', re.I),    u'april'),
                      (re.compile(u'\\bavr\\b', re.I), u'april'),
                      (re.compile(u'juil\\.', re.I),   u'july'),
@@ -265,8 +265,8 @@ DATE_TRANSLATE_FR = [(re.compile(u'janvier', re.I),   u'january'),
                      (re.compile(u'\\boct\\b', re.I), u'october'),
                      (re.compile(u'nov\.', re.I),     u'november'),
                      (re.compile(u'\\bnov\\b', re.I), u'november'),
-                     (re.compile(u'd[eé]c\\.', re.I), u'december'),
-                     (re.compile(u'\\bd[eé]c\\b', re.I), u'december'),
+                     (re.compile(u'd[eé]c\\.', re.I | re.U), u'december'),
+                     (re.compile(u'\\bd[eé]c\\b', re.I | re.U), u'december'),
                      (re.compile(u'lundi', re.I),     u'monday'),
                      (re.compile(u'mardi', re.I),     u'tuesday'),
                      (re.compile(u'mercredi', re.I),  u'wednesday'),
@@ -284,15 +284,16 @@ DATE_TRANSLATE_IT = [(re.compile(u'gennaio', re.I),      u'january'),
                      (re.compile(u'giugno', re.I),       u'june'),
                      (re.compile(u'luglio', re.I),       u'july'),
                      (re.compile(u'agosto', re.I),       u'august'),
+                     (re.compile(u'ago', re.I),          u'august'),
                      (re.compile(u'settembre', re.I),    u'september'),
                      (re.compile(u'ottobre', re.I),      u'october'),
                      (re.compile(u'novembre', re.I),     u'november'),
                      (re.compile(u'dicembre', re.I),     u'december'),
-                     (re.compile(u'luned[iì]', re.I),    u'monday'),
-                     (re.compile(u'marted[iì]', re.I),   u'tuesday'),
-                     (re.compile(u'mercoled[iì]', re.I), u'wednesday'),
-                     (re.compile(u'gioved[iì]', re.I),   u'thursday'),
-                     (re.compile(u'venerd[iì]', re.I),   u'friday'),
+                     (re.compile(u'luned[iì]', re.I | re.U),    u'monday'),
+                     (re.compile(u'marted[iì]', re.I | re.U),   u'tuesday'),
+                     (re.compile(u'mercoled[iì]', re.I | re.U), u'wednesday'),
+                     (re.compile(u'gioved[iì]', re.I | re.U),   u'thursday'),
+                     (re.compile(u'venerd[iì]', re.I | re.U),   u'friday'),
                      (re.compile(u'sabato', re.I),       u'saturday'),
                      (re.compile(u'domenica', re.I),     u'sunday')]
 
